@@ -2745,7 +2745,14 @@ module.exports = {
 		"26.6.0",
 		"26.6.1",
 		"26.6.2",
-		"26.6.3"
+		"26.6.3",
+		"26.6.4",
+		"26.6.5",
+		"26.6.6",
+		"26.6.7",
+		"26.6.8",
+		"26.6.9",
+		"26.6.10"
 	],
 	"118.0.5949.0": [
 		"27.0.0-alpha.1",
@@ -2851,7 +2858,23 @@ module.exports = {
 	],
 	"118.0.5993.159": [
 		"27.1.3",
-		"27.2.0"
+		"27.2.0",
+		"27.2.1",
+		"27.2.2",
+		"27.2.3",
+		"27.2.4",
+		"27.3.0",
+		"27.3.1",
+		"27.3.2",
+		"27.3.3",
+		"27.3.4",
+		"27.3.5",
+		"27.3.6",
+		"27.3.7",
+		"27.3.8",
+		"27.3.9",
+		"27.3.10",
+		"27.3.11"
 	],
 	"119.0.6045.0": [
 		"28.0.0-alpha.1",
@@ -2936,7 +2959,38 @@ module.exports = {
 		"28.0.0"
 	],
 	"120.0.6099.109": [
-		"28.1.0"
+		"28.1.0",
+		"28.1.1"
+	],
+	"120.0.6099.199": [
+		"28.1.2",
+		"28.1.3"
+	],
+	"120.0.6099.216": [
+		"28.1.4"
+	],
+	"120.0.6099.227": [
+		"28.2.0"
+	],
+	"120.0.6099.268": [
+		"28.2.1"
+	],
+	"120.0.6099.276": [
+		"28.2.2"
+	],
+	"120.0.6099.283": [
+		"28.2.3"
+	],
+	"120.0.6099.291": [
+		"28.2.4",
+		"28.2.5",
+		"28.2.6",
+		"28.2.7",
+		"28.2.8",
+		"28.2.9",
+		"28.2.10",
+		"28.3.0",
+		"28.3.1"
 	],
 	"121.0.6147.0": [
 		"29.0.0-alpha.1",
@@ -2955,11 +3009,57 @@ module.exports = {
 	"121.0.6159.0": [
 		"29.0.0-alpha.4",
 		"29.0.0-alpha.5",
+		"29.0.0-alpha.6",
+		"29.0.0-alpha.7",
 		"30.0.0-nightly.20231212",
 		"30.0.0-nightly.20231213",
 		"30.0.0-nightly.20231214",
 		"30.0.0-nightly.20231215",
-		"30.0.0-nightly.20231218"
+		"30.0.0-nightly.20231218",
+		"30.0.0-nightly.20240102"
+	],
+	"122.0.6194.0": [
+		"29.0.0-alpha.8",
+		"30.0.0-nightly.20240103",
+		"30.0.0-nightly.20240104",
+		"30.0.0-nightly.20240105",
+		"30.0.0-nightly.20240108",
+		"30.0.0-nightly.20240109",
+		"30.0.0-nightly.20240110"
+	],
+	"122.0.6236.2": [
+		"29.0.0-alpha.9",
+		"29.0.0-alpha.10",
+		"29.0.0-alpha.11",
+		"29.0.0-beta.1",
+		"29.0.0-beta.2",
+		"30.0.0-nightly.20240111",
+		"30.0.0-nightly.20240112",
+		"30.0.0-nightly.20240115",
+		"30.0.0-nightly.20240116",
+		"30.0.0-nightly.20240117",
+		"30.0.0-nightly.20240118",
+		"30.0.0-nightly.20240119",
+		"30.0.0-nightly.20240122",
+		"30.0.0-nightly.20240123",
+		"30.0.0-nightly.20240124",
+		"30.0.0-nightly.20240125"
+	],
+	"122.0.6261.6": [
+		"29.0.0-beta.3",
+		"29.0.0-beta.4"
+	],
+	"122.0.6261.18": [
+		"29.0.0-beta.5",
+		"29.0.0-beta.6",
+		"29.0.0-beta.7",
+		"29.0.0-beta.8",
+		"29.0.0-beta.9",
+		"29.0.0-beta.10",
+		"29.0.0-beta.11"
+	],
+	"122.0.6261.29": [
+		"29.0.0-beta.12"
 	],
 	"120.0.6078.0": [
 		"29.0.0-nightly.20231025",
@@ -2995,5 +3095,181 @@ module.exports = {
 		"29.0.0-nightly.20231124",
 		"29.0.0-nightly.20231127",
 		"29.0.0-nightly.20231128"
+	],
+	"122.0.6261.39": [
+		"29.0.0"
+	],
+	"122.0.6261.57": [
+		"29.0.1"
+	],
+	"122.0.6261.70": [
+		"29.1.0"
+	],
+	"122.0.6261.111": [
+		"29.1.1"
+	],
+	"122.0.6261.112": [
+		"29.1.2",
+		"29.1.3"
+	],
+	"122.0.6261.129": [
+		"29.1.4"
+	],
+	"122.0.6261.130": [
+		"29.1.5"
+	],
+	"122.0.6261.139": [
+		"29.1.6"
+	],
+	"122.0.6261.156": [
+		"29.2.0",
+		"29.3.0",
+		"29.3.1",
+		"29.3.2",
+		"29.3.3",
+		"29.4.0"
+	],
+	"123.0.6296.0": [
+		"30.0.0-alpha.1",
+		"30.0.0-nightly.20240215",
+		"30.0.0-nightly.20240216",
+		"30.0.0-nightly.20240219",
+		"30.0.0-nightly.20240220",
+		"30.0.0-nightly.20240221"
+	],
+	"123.0.6312.5": [
+		"30.0.0-alpha.2",
+		"31.0.0-nightly.20240222",
+		"31.0.0-nightly.20240223",
+		"31.0.0-nightly.20240226",
+		"31.0.0-nightly.20240227",
+		"31.0.0-nightly.20240228"
+	],
+	"124.0.6323.0": [
+		"30.0.0-alpha.3",
+		"30.0.0-alpha.4",
+		"31.0.0-nightly.20240229",
+		"31.0.0-nightly.20240301",
+		"31.0.0-nightly.20240304",
+		"31.0.0-nightly.20240305"
+	],
+	"124.0.6331.0": [
+		"30.0.0-alpha.5",
+		"30.0.0-alpha.6",
+		"31.0.0-nightly.20240306",
+		"31.0.0-nightly.20240307",
+		"31.0.0-nightly.20240308",
+		"31.0.0-nightly.20240311"
+	],
+	"124.0.6353.0": [
+		"30.0.0-alpha.7",
+		"31.0.0-nightly.20240313",
+		"31.0.0-nightly.20240314",
+		"31.0.0-nightly.20240315"
+	],
+	"124.0.6359.0": [
+		"30.0.0-beta.1",
+		"30.0.0-beta.2",
+		"31.0.0-nightly.20240318",
+		"31.0.0-nightly.20240319",
+		"31.0.0-nightly.20240320",
+		"31.0.0-nightly.20240321",
+		"31.0.0-nightly.20240325",
+		"31.0.0-nightly.20240327",
+		"31.0.0-nightly.20240328",
+		"31.0.0-nightly.20240329",
+		"31.0.0-nightly.20240401",
+		"31.0.0-nightly.20240402",
+		"31.0.0-nightly.20240404",
+		"31.0.0-nightly.20240405",
+		"31.0.0-nightly.20240408",
+		"31.0.0-nightly.20240409",
+		"31.0.0-nightly.20240410",
+		"31.0.0-nightly.20240411",
+		"31.0.0-nightly.20240412"
+	],
+	"124.0.6367.9": [
+		"30.0.0-beta.3",
+		"30.0.0-beta.4",
+		"30.0.0-beta.5"
+	],
+	"124.0.6367.18": [
+		"30.0.0-beta.6"
+	],
+	"124.0.6367.29": [
+		"30.0.0-beta.7",
+		"30.0.0-beta.8"
+	],
+	"123.0.6264.0": [
+		"30.0.0-nightly.20240126",
+		"30.0.0-nightly.20240129",
+		"30.0.0-nightly.20240130",
+		"30.0.0-nightly.20240131"
+	],
+	"123.0.6272.0": [
+		"30.0.0-nightly.20240201",
+		"30.0.0-nightly.20240202",
+		"30.0.0-nightly.20240205",
+		"30.0.0-nightly.20240206",
+		"30.0.0-nightly.20240207",
+		"30.0.0-nightly.20240208",
+		"30.0.0-nightly.20240209",
+		"30.0.0-nightly.20240212",
+		"30.0.0-nightly.20240213",
+		"30.0.0-nightly.20240214"
+	],
+	"124.0.6367.49": [
+		"30.0.0"
+	],
+	"124.0.6367.60": [
+		"30.0.1"
+	],
+	"124.0.6367.91": [
+		"30.0.2"
+	],
+	"124.0.6367.119": [
+		"30.0.3"
+	],
+	"124.0.6367.201": [
+		"30.0.4"
+	],
+	"124.0.6367.207": [
+		"30.0.5",
+		"30.0.6"
+	],
+	"125.0.6412.0": [
+		"31.0.0-alpha.1",
+		"31.0.0-alpha.2",
+		"31.0.0-alpha.3",
+		"31.0.0-alpha.4",
+		"31.0.0-alpha.5",
+		"32.0.0-nightly.20240418",
+		"32.0.0-nightly.20240419",
+		"32.0.0-nightly.20240422",
+		"32.0.0-nightly.20240423",
+		"32.0.0-nightly.20240424",
+		"32.0.0-nightly.20240425",
+		"32.0.0-nightly.20240426",
+		"32.0.0-nightly.20240429",
+		"32.0.0-nightly.20240430",
+		"32.0.0-nightly.20240501",
+		"32.0.0-nightly.20240503",
+		"32.0.0-nightly.20240506",
+		"32.0.0-nightly.20240507",
+		"32.0.0-nightly.20240508",
+		"32.0.0-nightly.20240509",
+		"32.0.0-nightly.20240510"
+	],
+	"126.0.6445.0": [
+		"31.0.0-beta.1",
+		"31.0.0-beta.2",
+		"31.0.0-beta.3",
+		"32.0.0-nightly.20240513",
+		"32.0.0-nightly.20240514",
+		"32.0.0-nightly.20240515",
+		"32.0.0-nightly.20240516"
+	],
+	"124.0.6351.0": [
+		"31.0.0-nightly.20240312"
 	]
 };
\ No newline at end of file
