@@ -1999,6 +1999,13 @@ module.exports = {
 	"26.6.1": "116.0.5845.228",
 	"26.6.2": "116.0.5845.228",
 	"26.6.3": "116.0.5845.228",
+	"26.6.4": "116.0.5845.228",
+	"26.6.5": "116.0.5845.228",
+	"26.6.6": "116.0.5845.228",
+	"26.6.7": "116.0.5845.228",
+	"26.6.8": "116.0.5845.228",
+	"26.6.9": "116.0.5845.228",
+	"26.6.10": "116.0.5845.228",
 	"27.0.0-alpha.1": "118.0.5949.0",
 	"27.0.0-alpha.2": "118.0.5949.0",
 	"27.0.0-alpha.3": "118.0.5949.0",
@@ -2074,6 +2081,22 @@ module.exports = {
 	"27.1.2": "118.0.5993.144",
 	"27.1.3": "118.0.5993.159",
 	"27.2.0": "118.0.5993.159",
+	"27.2.1": "118.0.5993.159",
+	"27.2.2": "118.0.5993.159",
+	"27.2.3": "118.0.5993.159",
+	"27.2.4": "118.0.5993.159",
+	"27.3.0": "118.0.5993.159",
+	"27.3.1": "118.0.5993.159",
+	"27.3.2": "118.0.5993.159",
+	"27.3.3": "118.0.5993.159",
+	"27.3.4": "118.0.5993.159",
+	"27.3.5": "118.0.5993.159",
+	"27.3.6": "118.0.5993.159",
+	"27.3.7": "118.0.5993.159",
+	"27.3.8": "118.0.5993.159",
+	"27.3.9": "118.0.5993.159",
+	"27.3.10": "118.0.5993.159",
+	"27.3.11": "118.0.5993.159",
 	"28.0.0-alpha.1": "119.0.6045.0",
 	"28.0.0-alpha.2": "119.0.6045.0",
 	"28.0.0-alpha.3": "119.0.6045.21",
@@ -2129,11 +2152,46 @@ module.exports = {
 	"28.0.0-nightly.20231011": "119.0.6045.0",
 	"28.0.0": "120.0.6099.56",
 	"28.1.0": "120.0.6099.109",
+	"28.1.1": "120.0.6099.109",
+	"28.1.2": "120.0.6099.199",
+	"28.1.3": "120.0.6099.199",
+	"28.1.4": "120.0.6099.216",
+	"28.2.0": "120.0.6099.227",
+	"28.2.1": "120.0.6099.268",
+	"28.2.2": "120.0.6099.276",
+	"28.2.3": "120.0.6099.283",
+	"28.2.4": "120.0.6099.291",
+	"28.2.5": "120.0.6099.291",
+	"28.2.6": "120.0.6099.291",
+	"28.2.7": "120.0.6099.291",
+	"28.2.8": "120.0.6099.291",
+	"28.2.9": "120.0.6099.291",
+	"28.2.10": "120.0.6099.291",
+	"28.3.0": "120.0.6099.291",
+	"28.3.1": "120.0.6099.291",
 	"29.0.0-alpha.1": "121.0.6147.0",
 	"29.0.0-alpha.2": "121.0.6147.0",
 	"29.0.0-alpha.3": "121.0.6147.0",
 	"29.0.0-alpha.4": "121.0.6159.0",
 	"29.0.0-alpha.5": "121.0.6159.0",
+	"29.0.0-alpha.6": "121.0.6159.0",
+	"29.0.0-alpha.7": "121.0.6159.0",
+	"29.0.0-alpha.8": "122.0.6194.0",
+	"29.0.0-alpha.9": "122.0.6236.2",
+	"29.0.0-alpha.10": "122.0.6236.2",
+	"29.0.0-alpha.11": "122.0.6236.2",
+	"29.0.0-beta.1": "122.0.6236.2",
+	"29.0.0-beta.2": "122.0.6236.2",
+	"29.0.0-beta.3": "122.0.6261.6",
+	"29.0.0-beta.4": "122.0.6261.6",
+	"29.0.0-beta.5": "122.0.6261.18",
+	"29.0.0-beta.6": "122.0.6261.18",
+	"29.0.0-beta.7": "122.0.6261.18",
+	"29.0.0-beta.8": "122.0.6261.18",
+	"29.0.0-beta.9": "122.0.6261.18",
+	"29.0.0-beta.10": "122.0.6261.18",
+	"29.0.0-beta.11": "122.0.6261.18",
+	"29.0.0-beta.12": "122.0.6261.29",
 	"29.0.0-nightly.20231012": "119.0.6045.0",
 	"29.0.0-nightly.20231013": "119.0.6045.0",
 	"29.0.0-nightly.20231016": "119.0.6045.0",
@@ -2174,6 +2232,36 @@ module.exports = {
 	"29.0.0-nightly.20231204": "121.0.6147.0",
 	"29.0.0-nightly.20231205": "121.0.6147.0",
 	"29.0.0-nightly.20231206": "121.0.6147.0",
+	"29.0.0": "122.0.6261.39",
+	"29.0.1": "122.0.6261.57",
+	"29.1.0": "122.0.6261.70",
+	"29.1.1": "122.0.6261.111",
+	"29.1.2": "122.0.6261.112",
+	"29.1.3": "122.0.6261.112",
+	"29.1.4": "122.0.6261.129",
+	"29.1.5": "122.0.6261.130",
+	"29.1.6": "122.0.6261.139",
+	"29.2.0": "122.0.6261.156",
+	"29.3.0": "122.0.6261.156",
+	"29.3.1": "122.0.6261.156",
+	"29.3.2": "122.0.6261.156",
+	"29.3.3": "122.0.6261.156",
+	"29.4.0": "122.0.6261.156",
+	"30.0.0-alpha.1": "123.0.6296.0",
+	"30.0.0-alpha.2": "123.0.6312.5",
+	"30.0.0-alpha.3": "124.0.6323.0",
+	"30.0.0-alpha.4": "124.0.6323.0",
+	"30.0.0-alpha.5": "124.0.6331.0",
+	"30.0.0-alpha.6": "124.0.6331.0",
+	"30.0.0-alpha.7": "124.0.6353.0",
+	"30.0.0-beta.1": "124.0.6359.0",
+	"30.0.0-beta.2": "124.0.6359.0",
+	"30.0.0-beta.3": "124.0.6367.9",
+	"30.0.0-beta.4": "124.0.6367.9",
+	"30.0.0-beta.5": "124.0.6367.9",
+	"30.0.0-beta.6": "124.0.6367.18",
+	"30.0.0-beta.7": "124.0.6367.29",
+	"30.0.0-beta.8": "124.0.6367.29",
 	"30.0.0-nightly.20231207": "121.0.6147.0",
 	"30.0.0-nightly.20231208": "121.0.6147.0",
 	"30.0.0-nightly.20231211": "121.0.6147.0",
@@ -2181,5 +2269,111 @@ module.exports = {
 	"30.0.0-nightly.20231213": "121.0.6159.0",
 	"30.0.0-nightly.20231214": "121.0.6159.0",
 	"30.0.0-nightly.20231215": "121.0.6159.0",
-	"30.0.0-nightly.20231218": "121.0.6159.0"
+	"30.0.0-nightly.20231218": "121.0.6159.0",
+	"30.0.0-nightly.20240102": "121.0.6159.0",
+	"30.0.0-nightly.20240103": "122.0.6194.0",
+	"30.0.0-nightly.20240104": "122.0.6194.0",
+	"30.0.0-nightly.20240105": "122.0.6194.0",
+	"30.0.0-nightly.20240108": "122.0.6194.0",
+	"30.0.0-nightly.20240109": "122.0.6194.0",
+	"30.0.0-nightly.20240110": "122.0.6194.0",
+	"30.0.0-nightly.20240111": "122.0.6236.2",
+	"30.0.0-nightly.20240112": "122.0.6236.2",
+	"30.0.0-nightly.20240115": "122.0.6236.2",
+	"30.0.0-nightly.20240116": "122.0.6236.2",
+	"30.0.0-nightly.20240117": "122.0.6236.2",
+	"30.0.0-nightly.20240118": "122.0.6236.2",
+	"30.0.0-nightly.20240119": "122.0.6236.2",
+	"30.0.0-nightly.20240122": "122.0.6236.2",
+	"30.0.0-nightly.20240123": "122.0.6236.2",
+	"30.0.0-nightly.20240124": "122.0.6236.2",
+	"30.0.0-nightly.20240125": "122.0.6236.2",
+	"30.0.0-nightly.20240126": "123.0.6264.0",
+	"30.0.0-nightly.20240129": "123.0.6264.0",
+	"30.0.0-nightly.20240130": "123.0.6264.0",
+	"30.0.0-nightly.20240131": "123.0.6264.0",
+	"30.0.0-nightly.20240201": "123.0.6272.0",
+	"30.0.0-nightly.20240202": "123.0.6272.0",
+	"30.0.0-nightly.20240205": "123.0.6272.0",
+	"30.0.0-nightly.20240206": "123.0.6272.0",
+	"30.0.0-nightly.20240207": "123.0.6272.0",
+	"30.0.0-nightly.20240208": "123.0.6272.0",
+	"30.0.0-nightly.20240209": "123.0.6272.0",
+	"30.0.0-nightly.20240212": "123.0.6272.0",
+	"30.0.0-nightly.20240213": "123.0.6272.0",
+	"30.0.0-nightly.20240214": "123.0.6272.0",
+	"30.0.0-nightly.20240215": "123.0.6296.0",
+	"30.0.0-nightly.20240216": "123.0.6296.0",
+	"30.0.0-nightly.20240219": "123.0.6296.0",
+	"30.0.0-nightly.20240220": "123.0.6296.0",
+	"30.0.0-nightly.20240221": "123.0.6296.0",
+	"30.0.0": "124.0.6367.49",
+	"30.0.1": "124.0.6367.60",
+	"30.0.2": "124.0.6367.91",
+	"30.0.3": "124.0.6367.119",
+	"30.0.4": "124.0.6367.201",
+	"30.0.5": "124.0.6367.207",
+	"30.0.6": "124.0.6367.207",
+	"31.0.0-alpha.1": "125.0.6412.0",
+	"31.0.0-alpha.2": "125.0.6412.0",
+	"31.0.0-alpha.3": "125.0.6412.0",
+	"31.0.0-alpha.4": "125.0.6412.0",
+	"31.0.0-alpha.5": "125.0.6412.0",
+	"31.0.0-beta.1": "126.0.6445.0",
+	"31.0.0-beta.2": "126.0.6445.0",
+	"31.0.0-beta.3": "126.0.6445.0",
+	"31.0.0-nightly.20240222": "123.0.6312.5",
+	"31.0.0-nightly.20240223": "123.0.6312.5",
+	"31.0.0-nightly.20240226": "123.0.6312.5",
+	"31.0.0-nightly.20240227": "123.0.6312.5",
+	"31.0.0-nightly.20240228": "123.0.6312.5",
+	"31.0.0-nightly.20240229": "124.0.6323.0",
+	"31.0.0-nightly.20240301": "124.0.6323.0",
+	"31.0.0-nightly.20240304": "124.0.6323.0",
+	"31.0.0-nightly.20240305": "124.0.6323.0",
+	"31.0.0-nightly.20240306": "124.0.6331.0",
+	"31.0.0-nightly.20240307": "124.0.6331.0",
+	"31.0.0-nightly.20240308": "124.0.6331.0",
+	"31.0.0-nightly.20240311": "124.0.6331.0",
+	"31.0.0-nightly.20240312": "124.0.6351.0",
+	"31.0.0-nightly.20240313": "124.0.6353.0",
+	"31.0.0-nightly.20240314": "124.0.6353.0",
+	"31.0.0-nightly.20240315": "124.0.6353.0",
+	"31.0.0-nightly.20240318": "124.0.6359.0",
+	"31.0.0-nightly.20240319": "124.0.6359.0",
+	"31.0.0-nightly.20240320": "124.0.6359.0",
+	"31.0.0-nightly.20240321": "124.0.6359.0",
+	"31.0.0-nightly.20240325": "124.0.6359.0",
+	"31.0.0-nightly.20240327": "124.0.6359.0",
+	"31.0.0-nightly.20240328": "124.0.6359.0",
+	"31.0.0-nightly.20240329": "124.0.6359.0",
+	"31.0.0-nightly.20240401": "124.0.6359.0",
+	"31.0.0-nightly.20240402": "124.0.6359.0",
+	"31.0.0-nightly.20240404": "124.0.6359.0",
+	"31.0.0-nightly.20240405": "124.0.6359.0",
+	"31.0.0-nightly.20240408": "124.0.6359.0",
+	"31.0.0-nightly.20240409": "124.0.6359.0",
+	"31.0.0-nightly.20240410": "124.0.6359.0",
+	"31.0.0-nightly.20240411": "124.0.6359.0",
+	"31.0.0-nightly.20240412": "124.0.6359.0",
+	"32.0.0-nightly.20240418": "125.0.6412.0",
+	"32.0.0-nightly.20240419": "125.0.6412.0",
+	"32.0.0-nightly.20240422": "125.0.6412.0",
+	"32.0.0-nightly.20240423": "125.0.6412.0",
+	"32.0.0-nightly.20240424": "125.0.6412.0",
+	"32.0.0-nightly.20240425": "125.0.6412.0",
+	"32.0.0-nightly.20240426": "125.0.6412.0",
+	"32.0.0-nightly.20240429": "125.0.6412.0",
+	"32.0.0-nightly.20240430": "125.0.6412.0",
+	"32.0.0-nightly.20240501": "125.0.6412.0",
+	"32.0.0-nightly.20240503": "125.0.6412.0",
+	"32.0.0-nightly.20240506": "125.0.6412.0",
+	"32.0.0-nightly.20240507": "125.0.6412.0",
+	"32.0.0-nightly.20240508": "125.0.6412.0",
+	"32.0.0-nightly.20240509": "125.0.6412.0",
+	"32.0.0-nightly.20240510": "125.0.6412.0",
+	"32.0.0-nightly.20240513": "126.0.6445.0",
+	"32.0.0-nightly.20240514": "126.0.6445.0",
+	"32.0.0-nightly.20240515": "126.0.6445.0",
+	"32.0.0-nightly.20240516": "126.0.6445.0"
 };
\ No newline at end of file
